const path = require('path')
const webpack = require('webpack')
const devConfig = require('@s-ui/bundler/webpack.config.dev')

const removePlugin = name => plugins => {
  const pos = plugins
    .map(p => p.constructor.toString())
    .findIndex(string => string.match(name))
  return [...plugins.slice(0, pos), ...plugins.slice(pos + 1)]
}

const pipe = (...funcs) => arg =>
  funcs.reduce((value, func) => func(value), arg)

const pluginsWithoutHtml = pipe(removePlugin('HtmlWebpackPlugin'))(
  devConfig.plugins
)

const plugins = [
  new webpack.HotModuleReplacementPlugin(),
  ...pluginsWithoutHtml
]

module.exports = ({address, port}) =>
  webpack({
    ...devConfig,
    context: path.resolve(process.cwd(), 'src'),
    entry: [
      // `webpack-hot-middleware/client?path=http://${address}:${port}/__ping`,
      `./index.js`
    ],
    output: {
      path: '/',
      publicPath: `http://${address}:${port}/`,
      filename: 'bundle.js',
      jsonpFunction: `webpackJsonp`
    },
    plugins
  })
