import {expect} from 'chai'
import sinon from 'sinon'
import loader from '../../src/analytics/loader'
const visitorHandler = require('../../src/analytics/visitorIdHandler')
const segmentWrapper = require('../../src/analytics/segmentWrapper')
const clickListener = require('../../src/analytics/clickListener')
const idSync = require('../../src/analytics/idSync')

describe('when analytics module is loaded', () => {
  let visitorHandlerStub
  let segmentWrapperStub
  let clickListenerStub
  let idSyncStub

  beforeEach(() => {
    visitorHandlerStub = sinon.stub(visitorHandler, 'default').resolves({
      infojobsVisitorId: 'fakeInfojobsId',
      adobeVisitorId: 'fakeAdobeId'
    })
    segmentWrapperStub = sinon.stub(segmentWrapper, 'default').returns({})
    clickListenerStub = sinon.stub(clickListener, 'default').returns(true)
    idSyncStub = sinon.stub(idSync, 'default').resolves(true)
  })

  afterEach(() => {
    visitorHandlerStub.restore()
    segmentWrapperStub.restore()
    visitorHandlerStub.restore()
    clickListenerStub.restore()
    idSyncStub.restore()
  })

  it('should pass the infojobs id as visitorId to the segmentWrapper module', done => {
    loader()
      .then(() => {
        expect(segmentWrapperStub.firstCall.args[0]).to.deep.equal({
          visitorId: 'fakeInfojobsId'
        })
        done()
      })
      .catch(done)
  })

  it('should pass by both ids to the sync module', done => {
    loader()
      .then(() => {
        expect(idSyncStub.firstCall.args[0]).to.deep.equal({
          infojobsVisitorId: 'fakeInfojobsId',
          adobeVisitorId: 'fakeAdobeId'
        })
        done()
      })
      .catch(done)
  })
})
